You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@usergrid.apache.org by sf...@apache.org on 2015/02/27 00:23:54 UTC

[07/27] incubator-usergrid git commit: [USERGRID-331] Adding additional checks for correct username on returned entity

[USERGRID-331] Adding additional checks for correct username on returned entity


Project: http://git-wip-us.apache.org/repos/asf/incubator-usergrid/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-usergrid/commit/55dc7448
Tree: http://git-wip-us.apache.org/repos/asf/incubator-usergrid/tree/55dc7448
Diff: http://git-wip-us.apache.org/repos/asf/incubator-usergrid/diff/55dc7448

Branch: refs/heads/USERGRID-273-indexbuffer
Commit: 55dc744870e880eb17774a1886e7ce2a4c78a074
Parents: 02c0e2f
Author: ryan bridges <rb...@apigee.com>
Authored: Fri Jan 23 18:16:33 2015 -0500
Committer: ryan bridges <rb...@apigee.com>
Committed: Thu Feb 5 11:59:56 2015 -0500

----------------------------------------------------------------------
 .../rest/management/organizations/AdminEmailEncodingIT.java  | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-usergrid/blob/55dc7448/stack/rest/src/test/java/org/apache/usergrid/rest/management/organizations/AdminEmailEncodingIT.java
----------------------------------------------------------------------
diff --git a/stack/rest/src/test/java/org/apache/usergrid/rest/management/organizations/AdminEmailEncodingIT.java b/stack/rest/src/test/java/org/apache/usergrid/rest/management/organizations/AdminEmailEncodingIT.java
index 22dafdc..648abd1 100644
--- a/stack/rest/src/test/java/org/apache/usergrid/rest/management/organizations/AdminEmailEncodingIT.java
+++ b/stack/rest/src/test/java/org/apache/usergrid/rest/management/organizations/AdminEmailEncodingIT.java
@@ -100,8 +100,6 @@ public class AdminEmailEncodingIT extends AbstractRestIT {
         String unique = UUID.randomUUID().toString();
         String org = "org_getTokenDash" + unique;
         String app = "app_getTokenDash" + unique;
-        org = org.toLowerCase();
-        app = app.toLowerCase();
 
         //Username and password
         String username = "testuser" + unique;
@@ -125,13 +123,15 @@ public class AdminEmailEncodingIT extends AbstractRestIT {
         //Create an application within the organization
         clientSetup.getRestClient().management().orgs().organization(organization.getName()).app().post(new Application(app));
 
-        //retrieve the new management user by username and ensure the email address matches the input
+        //retrieve the new management user by username and ensure the username and email address matches the input
         Entity me = clientSetup.getRestClient().management().users().entity(username).get();
         assertEquals(email, me.get("email"));
+        assertEquals(username, me.get("username"));
 
         //retrieve the new management user by email and ensure the email address matches the input
         me = clientSetup.getRestClient().management().users().entity(email).get();
         assertEquals(email, me.get("email"));
+        assertEquals(username, me.get("username"));
 
     }
 }
@@ -125,13 +123,15 @@ public class AdminEmailEncodingIT extends AbstractRestIT {
 
-        //retrieve the new management user by email and ensure the email address matches the input
+        //retrieve the new management user by email and ensure the username and email address matches the input
         me = clientSetup.getRestClient().management().users().entity(email).get();
         assertEquals(email, me.get("email"));